@@ -16,9 +16,12 @@ impl Default for PostgresQueryBuilder {
     }
 }
 
-impl GenericBuilder for PostgresQueryBuilder {
-    type QueryBuilder = Self;
-    type TableBuilder = Self;
-    type IndexBuilder = Self;
-    type ForeignKeyBuilder = Self;
-}
\ No newline at end of file
+impl GenericBuilder for PostgresQueryBuilder {}
+
+impl SchemaBuilder for PostgresQueryBuilder {}
+
+impl QuotedBuilder for PostgresQueryBuilder {
+    fn quote(&self) -> char {
+        '"'
+    }
+}
