@@ -1,14 +1,13 @@
 use crate::types::*;
-use std::rc::Rc;
 
 /// Specification of a foreign key
 #[derive(Debug, Clone)]
 pub struct TableForeignKey {
     pub(crate) name: Option<String>,
-    pub(crate) table: Option<Rc<dyn Iden>>,
-    pub(crate) ref_table: Option<Rc<dyn Iden>>,
-    pub(crate) columns: Vec<Rc<dyn Iden>>,
-    pub(crate) ref_columns: Vec<Rc<dyn Iden>>,
+    pub(crate) table: Option<DynIden>,
+    pub(crate) ref_table: Option<DynIden>,
+    pub(crate) columns: Vec<DynIden>,
+    pub(crate) ref_columns: Vec<DynIden>,
     pub(crate) on_delete: Option<ForeignKeyAction>,
     pub(crate) on_update: Option<ForeignKeyAction>,
 }
@@ -96,4 +95,17 @@ impl TableForeignKey {
         self.on_update = Some(action);
         self
     }
+
+    pub fn get_ref_table(&self) -> Option<String> {
+        self.ref_table.as_ref().map(|ref_tbl| ref_tbl.to_string())
+    }
+    pub fn get_columns(&self) -> Vec<String> {
+        self.columns.iter().map(|col| col.to_string()).collect()
+    }
+    pub fn get_ref_columns(&self) -> Vec<String> {
+        self.ref_columns
+            .iter()
+            .map(|ref_col| ref_col.to_string())
+            .collect()
+    }
 }
