@@ -1,6 +1,5 @@
 use super::common::*;
 use crate::{backend::SchemaBuilder, prepare::*, types::*, SchemaStatementBuilder};
-use std::rc::Rc;
 
 /// Create an index for an existing table
 ///
@@ -99,7 +98,7 @@ use std::rc::Rc;
 /// ```
 #[derive(Debug, Clone)]
 pub struct IndexCreateStatement {
-    pub(crate) table: Option<Rc<dyn Iden>>,
+    pub(crate) table: Option<DynIden>,
     pub(crate) index: TableIndex,
     pub(crate) primary: bool,
     pub(crate) unique: bool,
@@ -112,7 +111,7 @@ pub enum IndexType {
     BTree,
     FullText,
     Hash,
-    Custom(Rc<dyn Iden>),
+    Custom(DynIden),
 }
 
 impl Default for IndexCreateStatement {
@@ -144,7 +143,7 @@ impl IndexCreateStatement {
     where
         T: Iden,
     {
-        self.table = Some(Rc::new(table));
+        self.table = Some(SeaRc::new(table));
         self
     }
 
@@ -181,6 +180,14 @@ impl IndexCreateStatement {
         self.index_type = Some(index_type);
         self
     }
+
+    pub fn is_primary_key(&self) -> bool {
+        self.primary
+    }
+
+    pub fn get_index_spec(&self) -> &TableIndex {
+        &self.index
+    }
 }
 
 impl SchemaStatementBuilder for IndexCreateStatement {
