@@ -165,7 +165,10 @@ impl ConditionalStatement for DeleteStatement {
         self
     }
 
-    fn cond_where<C>(&mut self, condition: C) -> &mut Self where C: IntoCondition {
+    fn cond_where<C>(&mut self, condition: C) -> &mut Self
+    where
+        C: IntoCondition,
+    {
         self.wherei.add_condition(condition.into_condition());
         self
     }
