@@ -1,5 +1,4 @@
 use crate::{backend::SchemaBuilder, prepare::*, types::*, SchemaStatementBuilder};
-use std::rc::Rc;
 
 /// Rename a table
 ///
@@ -27,8 +26,8 @@ use std::rc::Rc;
 /// ```
 #[derive(Debug, Clone)]
 pub struct TableRenameStatement {
-    pub(crate) from_name: Option<Rc<dyn Iden>>,
-    pub(crate) to_name: Option<Rc<dyn Iden>>,
+    pub(crate) from_name: Option<DynIden>,
+    pub(crate) to_name: Option<DynIden>,
 }
 
 impl Default for TableRenameStatement {
@@ -52,8 +51,8 @@ impl TableRenameStatement {
         T: Iden,
         R: Iden,
     {
-        self.from_name = Some(Rc::new(from_name));
-        self.to_name = Some(Rc::new(to_name));
+        self.from_name = Some(SeaRc::new(from_name));
+        self.to_name = Some(SeaRc::new(to_name));
         self
     }
 }
