@@ -1,9 +1,8 @@
+use sea_query::{tests_cfg::*, *};
+
 mod foreign_key;
 mod index;
-mod online;
 #[allow(deprecated)]
 mod query;
 mod table;
 mod types;
-
-use sea_query_test::*;
